@@ -1,7 +1,8 @@
 package Test::Data;
 use strict;
 
-our $VERSION = '1.240_03';
+use vars qw($VERSION);
+$VERSION = '1.23';
 
 use Carp qw(carp);
 
@@ -28,22 +29,27 @@ and values of data and variables.
 
 $Exporter::Verbose = 0;
 
-sub import {
+sub import 
+	{
     my $self   = shift;
     my $caller = caller;
 
-	foreach my $package ( @_ ) {
+	foreach my $package ( @_ )
+		{
 		my $full_package = "Test::Data::$package";
 		eval{ eval "require $full_package" };
-		if( $@ ) {
+		if( $@ )
+			{
 			carp "Could not require Test::Data::$package: $@";
 			}
 
-		$full_package->Exporter::export($caller);
+		$full_package->export($caller);
 		}
 
 	}
 
+sub VERSION { return $VERSION }
+
 =head2 Functions
 
 Plug-in modules define functions for each data type.  See the
@@ -53,7 +59,7 @@ appropriate module.
 
 The Test::Data module simply emports functions from Test::Data::*
 modules.  Each module defines a self-contained function, and puts
-that function name into @EXPORT.  Test::Data defines its own
+that function name into @EXPORT.  Test::Data defines its own 
 import function, but that does not matter to the plug-in modules.
 
 If you want to write a plug-in module, follow the example of one
@@ -65,7 +71,7 @@ find it.
 
 I'm not a very good Windows Perler, so some things don't work as
 they should on Windows. I recently got a Windows box so I can
-test things, but if you run into problems, I can use all the
+test things, but if you run into problems, I can use all the 
 patches or advice you care to send.
 
 =head1 SEE ALSO
@@ -88,7 +94,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2002-2016, brian d foy <bdfoy@cpan.org>. All rights reserved.
+Copyright (c) 2002-2012 brian d foy.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
