@@ -1,12 +1,14 @@
 package Test::Data::Array;
 use strict;
 
-use Exporter qw(import);
-our $VERSION = '1.240_03';
+use base qw(Exporter);
+use vars qw(@EXPORT $VERSION);
+$VERSION = '1.23';
 
-our @EXPORT = qw( array_any_ok array_none_ok array_once_ok array_multiple_ok
+
+@EXPORT = qw( array_any_ok array_none_ok array_once_ok array_multiple_ok
 	array_max_ok array_min_ok array_maxstr_ok array_minstr_ok array_sum_ok
-	array_length_ok array_empty_ok
+	array_length_ok array_empty_ok 
 	array_sortedstr_ascending_ok array_sortedstr_descending_ok
 	array_sorted_ascending_ok array_sorted_descending_ok
 	);
@@ -38,12 +40,14 @@ Ok if any element of ARRAY is ITEM.
 
 =cut
 
-sub array_any_ok($\@;$) {
+sub array_any_ok($\@;$)
+	{
 	my $element = shift;
 	my $array   = shift;
 	my $name    = shift || 'Array contains item';
 
-	foreach my $try ( @$array ) {
+	foreach my $try ( @$array )
+		{
 		next unless $try eq $element;
 		$Test->ok( 1, $name );
 		return;
@@ -58,12 +62,14 @@ Ok if no element of ARRAY is ITEM.
 
 =cut
 
-sub array_none_ok($\@;$) {
+sub array_none_ok($\@;$)
+	{
 	my $element = shift;
 	my $array   = shift;
 	my $name    = shift || 'Array does not contain item';
 
-	foreach my $try ( @$array ) {
+	foreach my $try ( @$array )
+		{
 		next unless $try eq $element;
 		$Test->ok( 0, $name );
 		return;
@@ -78,7 +84,8 @@ Ok if only one element of ARRAY is ITEM.
 
 =cut
 
-sub array_once_ok($\@;$) {
+sub array_once_ok($\@;$)
+	{
 	my $element = shift;
 	my $array   = shift;
 	my $name    = shift || 'Array contains item only once';
@@ -89,7 +96,7 @@ sub array_once_ok($\@;$) {
 	foreach my $item ( @$array ) { ++$seen{$item} }
 
 	$ok = 1 if( defined $seen{$element} and $seen{$element} == 1 );
-
+		
 	$Test->ok( $ok, $name );
 	}
 
@@ -99,7 +106,8 @@ Ok if more than one element of ARRAY is ITEM.
 
 =cut
 
-sub array_multiple_ok($\@;$) {
+sub array_multiple_ok($\@;$)
+	{
 	my $element = shift;
 	my $array   = shift;
 	my $name    = shift || 'Array contains item at least once';
@@ -120,7 +128,8 @@ or equal to NUMBER.
 
 =cut
 
-sub array_max_ok($\@;$) {
+sub array_max_ok($\@;$)
+	{
 	my $item   = shift;
 	my $array  = shift;
 	my $name   = shift || 'Array maximum is okay';
@@ -137,7 +146,8 @@ or equal to NUMBER.
 
 =cut
 
-sub array_min_ok($\@;$) {
+sub array_min_ok($\@;$)
+	{
 	my $item   = shift;
 	my $array  = shift;
 	my $name   = shift || 'Array minimum is okay';
@@ -154,7 +164,8 @@ or equal to MAX.
 
 =cut
 
-sub array_maxstr_ok($\@;$) {
+sub array_maxstr_ok($\@;$)
+	{
 	my $item   = shift;
 	my $array  = shift;
 	my $name   = shift || 'Array maximum string is okay';
@@ -171,7 +182,8 @@ or equal to MAX.
 
 =cut
 
-sub array_minstr_ok($\@;$) {
+sub array_minstr_ok($\@;$)
+	{
 	my $item   = shift;
 	my $array  = shift;
 	my $name   = shift || 'Array minimum string is okay';
@@ -187,7 +199,8 @@ Ok if the numerical sum of ARRAY is SUM.
 
 =cut
 
-sub array_sum_ok($\@;$) {
+sub array_sum_ok($\@;$)
+	{
 	my $sum    = shift;
 	my $array  = shift;
 	my $name   = shift || 'Array sum is correct';
@@ -203,7 +216,8 @@ Ok if the array contains no elements.
 
 =cut
 
-sub array_empty_ok(\@;$) {
+sub array_empty_ok(\@;$)
+	{
 	my $array = shift;
 	my $name  = shift || 'Array is empty';
 
@@ -217,7 +231,8 @@ Ok if the array contains LENGTH number of elements.
 
 =cut
 
-sub array_length_ok(\@$;$) {
+sub array_length_ok(\@$;$)
+	{
 	my $array  = shift;
 	my $length = shift;
 	my $name   = shift || 'Array length is correct';
@@ -232,40 +247,45 @@ to the one before.
 
 =cut
 
-sub array_sortedstr_ascending_ok(\@;$) {
+sub array_sortedstr_ascending_ok(\@;$)
+	{
 	my $array = shift;
 	my $name  = shift || 'Array is in ascending order';
-
+	
 	my $last_seen = 0;
-
-	ELEMENT: foreach my $index ( 1 .. $#$array ) {
-		if( $array->[ $index ] ge $array->[ $index - 1 ] ) {
+	
+	ELEMENT: foreach my $index ( 1 .. $#$array )
+		{
+		if( $array->[ $index ] ge $array->[ $index - 1 ] )
+			{
 			$last_seen = $index;
 			next;
 			}
 		last;
 		}
-
-	$last_seen == $#$array ?
-		$Test->ok( 1, $name )
-			:
+		
+	$last_seen == $#$array ?  
+		$Test->ok( 1, $name ) 
+			: 
 		$Test->ok( 0, $name );
 	}
-
+	
 =item array_sortedstr_descending_ok( ARRAY, [, NAME] )
 
 Ok if each succeeding element is asciibetically less than or equal to
-the one before.
+the one before. 
 
 =cut
 
-sub array_sortedstr_descending_ok(\@;$) {
+sub array_sortedstr_descending_ok(\@;$)
+	{
 	my $array = shift;
 	my $name  = shift || 'Array is in descending order';
-
+	
 	my $last_seen = 0;
-
-	ELEMENT: foreach my $index ( 1 .. $#$array ) {
+	
+	ELEMENT: foreach my $index ( 1 .. $#$array )
+		{
 		if( $array->[ $index ] le $array->[ $index - 1 ] )
 			{
 			$last_seen = $index;
@@ -273,10 +293,10 @@ sub array_sortedstr_descending_ok(\@;$) {
 			}
 		last;
 		}
-
-	$last_seen == $#$array ?
-		$Test->ok( 1, $name )
-			:
+		
+	$last_seen == $#$array ?  
+		$Test->ok( 1, $name ) 
+			: 
 		$Test->ok( 0, $name );
 	}
 
@@ -287,53 +307,59 @@ to the one before.
 
 =cut
 
-sub array_sorted_ascending_ok(\@;$) {
+sub array_sorted_ascending_ok(\@;$)
+	{
 	my $array = shift;
 	my $name  = shift || 'Array is in ascending order';
-
+	
 	my $last_seen = 0;
-
-	ELEMENT: foreach my $index ( 1 .. $#$array ) {
-		if( $array->[ $index ] >= $array->[ $index - 1 ] ) {
+	
+	ELEMENT: foreach my $index ( 1 .. $#$array )
+		{
+		if( $array->[ $index ] >= $array->[ $index - 1 ] )
+			{
 			$last_seen = $index;
 			next;
 			}
 		last;
 		}
-
-	$last_seen == $#$array ?
-		$Test->ok( 1, $name )
-			:
+		
+	$last_seen == $#$array ?  
+		$Test->ok( 1, $name ) 
+			: 
 		$Test->ok( 0, $name );
 	}
-
+	
 =item array_sorted_descending_ok( ARRAY, [, NAME] )
 
 Ok if each succeeding element is numerically less than or equal to
-the one before.
+the one before. 
 
 =cut
 
-sub array_sorted_descending_ok(\@;$) {
+sub array_sorted_descending_ok(\@;$)
+	{
 	my $array = shift;
 	my $name  = shift || 'Array is in descending order';
-
+	
 	my $last_seen = 0;
-
-	ELEMENT: foreach my $index ( 1 .. $#$array ) {
-		if( $array->[ $index ] <= $array->[ $index - 1 ] ) {
+	
+	ELEMENT: foreach my $index ( 1 .. $#$array )
+		{
+		if( $array->[ $index ] <= $array->[ $index - 1 ] )
+			{
 			$last_seen = $index;
 			next;
 			}
 		last;
 		}
-
-	$last_seen == $#$array ?
-		$Test->ok( 1, $name )
-			:
+		
+	$last_seen == $#$array ?  
+		$Test->ok( 1, $name ) 
+			: 
 		$Test->ok( 0, $name );
 	}
-
+	
 =back
 
 =head1 SEE ALSO
@@ -356,7 +382,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2002-2016, brian d foy <bdfoy@cpan.org>. All rights reserved.
+Copyright (c) 2002-2012 brian d foy.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
