@@ -1,13 +1,14 @@
 package Test::Data::Hash;
 use strict;
 
-use Exporter qw(import);
+use base qw(Exporter);
+use vars qw(@EXPORT $VERSION);
 
-our @EXPORT = qw(exists_ok not_exists_ok
+@EXPORT = qw(exists_ok not_exists_ok
 	hash_value_defined_ok hash_value_undef_ok
 	hash_value_true_ok hash_value_false_ok);
 
-our $VERSION = '1.240_03';
+$VERSION = '1.23';
 
 use Test::Builder;
 my $Test = Test::Builder->new();
@@ -86,7 +87,8 @@ does not create KEY in HASH.
 
 =cut
 
-sub hash_value_undef_ok($\%;$) {
+sub hash_value_undef_ok($\%;$)
+	{
 	my $key  = shift;
 	my $hash = shift;
 	my $name = shift || "Hash value for key [$key] is undef";
@@ -101,7 +103,8 @@ does not create KEY in HASH.
 
 =cut
 
-sub hash_value_true_ok($\%;$) {
+sub hash_value_true_ok($\%;$)
+	{
 	my $key  = shift;
 	my $hash = shift;
 	my $name = shift || "Hash value for key [$key] is true";
@@ -116,7 +119,8 @@ does not create KEY in HASH.
 
 =cut
 
-sub hash_value_false_ok($\%;$) {
+sub hash_value_false_ok($\%;$)
+	{
 	my $key  = shift;
 	my $hash = shift;
 	my $name = shift || "Hash value for key [$key] is false";
@@ -146,7 +150,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2002-2016, brian d foy <bdfoy@cpan.org>. All rights reserved.
+Copyright (c) 2002-2012 brian d foy.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
